# -*- coding: utf-8 -*-
import sys, pyperclip, webbrowser

def search():
    # get search param from command line argument (if given)
    if len(sys.argv) > 1:
        search_param = ' '.join(sys.argv[1:])
    # get search param from clipboard using pyperclip library
    else:
        search_param = pyperclip.paste()
        print(search_param)
    webbrowser.open('https://www.google.com/maps/place/' + search_param)




# -*- coding: utf-8 -*-

# Learn more: https://github.com/kennethreitz/setup.py

from setuptools import setup, find_packages

with open('README.rst') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()


setup(
    name='searchClipboard',
    version='0.1.1',
    description='search google for current clipboard contents',
    long_description=readme,
    author='Aashray Anand',
    author_email='aashrayanand01@gmail.com',
    url='https://github.com/AashrayAnand/searchClipboard',
    license=license,
    packages=find_packages(exclude=('tests', 'docs')),
    scripts=['bin/search-Clipboard'],
    install_requires=['pyperclip',],
)

